
*Title: Emphasis-based or Opinion-based Policy Change? How Political Parties Respond to the Electorate's Issue Salience of the Environmental Issue
*Author: Robin Hetzel, Heinrich-Heine-University Düsseldorf, Germany

set more off
capture log close
log using Responsiveness_Paper_log, replace
cd "set your working directionary"
use "ZA5102_v2-0-0.dta" 

***Preparation of The Euromanifesto Dataset***
* deleting of all not needed variables
keep za_nr total partyname initials year EPseats country region country_year ///
emcs emcs_year ees eep member partyinfo pfamily mfamily ofamily EPvote ///
EPseatsum group manif NATvote NATseats gov pm left environ liberta rile_mrg ///
per_v1_401a per_v2_401a per_v3_401a per_v1_410a per_v2_410a per_v3_410a ///
per_v1_416a per_v2_416a per_v3_416a per_v1_501a per_v2_501a per_v3_501a ///
per_v1_7031b per_v2_7031b per_v3_7031b per_v1_7031a per_v2_7031a per_v3_7031a


*deleting of all not needed years & countries
drop if year == 1979
drop if year==1984
drop if year==1987
drop if year==1995
drop if year==1996
drop if country==36
drop if country==37
drop if country==10
drop if country==80
drop if country==81
drop if country==93
drop if country==88

*merging of the Euromanifesto and European Voter Study 
merge 1:m emcs_year using "aggregated_data"

tab _merge if _merge==2

keep if _merge==3
duplicates report emcs year country emcs_year

*preparation of the merged dataset
rename MIPEnvironmentLastNE MIP_Envi_LastNE
rename MIPClimateChangelastNE MIP_CC_LastNE
rename VoteLastNationalElectionTota Vote_LastNE_Total
rename MIPEnvironmentVoteIntentionN MIP_Envi_VI_NE
rename MIPClimateChangeVoteIntentio MIP_CC_VI_NE
rename VoteIntentionNETotal VI_NE_Total
rename MIPEnvironmentLastEPElection MIP_Envi_LastEP
rename MIPClimateChangeLastEPElect MIP_CC_LastEP
rename VoteLastEPElectionTotal Vote_LastEP_Total
rename MIPEnvironmentClimateChange MIP_Envi_CC
rename AverageVoterTotalNumber Mean_Voter_Total
rename MIPEnvironmentPotentialVoters MIP_Envi_PV
rename MIPClimateChangePotentialVot MIP_CC_PV
rename PotentialVotersTotal PV_Total

drop za_nr
drop Country partyname
rename Party party
order party, before(year) 
drop initials
sort year country

*deleting all parties with less than three observations
drop if emcs==87951 |emcs==11952 |emcs==32110 |emcs==31110 |emcs==31223 ///
|emcs==31322 |emcs==32310 |emcs==32513 |emcs==53220 |emcs==32912 |emcs==33930 ///
|emcs==33512 |emcs==33903 |emcs==33907 |emcs==35220 |emcs==87110 |emcs==51953 ///
|emcs==42422 |emcs==42421 |emcs==35319

*creating variables that combine all three manifesto levels (national, European, unspecified)
generate per401a_all = per_v1_401a + per_v2_401a + per_v3_401a
label variable per401a_all "Free Enterprise - positive - all levels"
generate per410a_all = per_v1_410a + per_v2_410a + per_v3_410a
label variable per410a_all "Productivity - positive - all levels"
generate per416a_all = per_v1_416a + per_v2_416a + per_v3_416a
label variable per416a_all "Anti-Growth Economy - positive - all levels"
generate per501a_all = per_v1_501a + per_v2_501a + per_v3_501a
label variable per501a_all "Environmental Protection - positive - all levels"
generate per7031a_all = per_v1_7031a + per_v2_7031a + per_v3_7031a
label variable per7031a_all "Agriculture and Farmers - positive - all levels"

*creating a variable for absolute number of quasi sentences (not percentage)
generate abs401a_all = per401a_all * total /100
label variable abs401a_all "Free Enterprise Absolute Number - positive - all levels"
generate abs410a_all = per410a_all * total /100
label variable abs410a_all "Productivity Absolute Number - positive - all levels"
generate abs7031a_all = per7031a_all * total /100
label variable abs7031a_all "Agriculture and Farmers Absolute Number - positive - all levels"
generate abs416a_all = per416a_all * total /100
label variable abs416a_all "Anti-Growth Economy Absolute Number - positive - all levels"
generate abs501a_all = per501a_all * total /100
label variable abs501a_all "Environmental Protection Absolute Number - positive - all levels"

*creating the position shift variable (following Abou-Chadi et al. 2019)
generate envi_position = log(abs401a_all + abs410a_all + abs7031a_all + 0.5) - log(abs501a_all + abs416a_all + 0.5)
label variable envi_position "Position on Environmental Issue"
sum envi_position

xtset emcs year, delta(5)
gen position_shift = envi_position-L.envi_position
label variable position_shift "Shift of Parties' Position"


*creating the salience shift variable (following Abou-Chadi et al. 2019)
generate envi_salience = per501a_all + per416a_all
label variable envi_salience "Salience of Environmental Issue"
sum envi_salience

xtset emcs year, delta(5)
gen salience_shift = envi_salience-L.envi_salience
label variable salience_shift "Shift of Parties' Salience"


*recoding the missing values from the European Voter Study
replace MIP_Envi_LastNE = . if MIP_Envi_LastNE==9999 |MIP_Envi_LastNE==999
replace MIP_CC_LastNE = . if MIP_CC_LastNE==9999 |MIP_CC_LastNE==999
replace Vote_LastNE_Total = . if Vote_LastNE_Total==9999 |Vote_LastNE_Total==999
replace MIP_Envi_VI_NE = . if MIP_Envi_VI_NE==9999 |MIP_Envi_VI_NE==999
replace MIP_CC_VI_NE = . if MIP_CC_VI_NE==9999 |MIP_CC_VI_NE==999
replace VI_NE_Total = . if VI_NE_Total==9999 |VI_NE_Total==999
replace MIP_Envi_LastEP = . if MIP_Envi_LastEP==9999 |MIP_Envi_LastEP==999
replace MIP_CC_LastEP = . if MIP_CC_LastEP==9999 |MIP_CC_LastEP==999
replace Vote_LastEP_Total = . if Vote_LastEP_Total==9999 |Vote_LastEP_Total==999
replace MIP_Envi_PV = . if MIP_Envi_PV==9999 |MIP_Envi_PV==999
replace MIP_CC_PV = . if MIP_CC_PV==9999 |MIP_CC_PV==999
replace PV_Total = . if PV_Total==9999 |PV_Total==999
replace MIP_Envi_CC = . if MIP_Envi_CC==9999 |MIP_Envi_CC==9999
replace Mean_Voter_Total = . if Mean_Voter_Total==9999 |Mean_Voter_Total==999

*creating the independent variables
*Party Supporter
generate VoterSalience_LastNE = (MIP_Envi_LastNE + MIP_CC_LastNE) / Vote_LastNE_Total *100
label variable VoterSalience_LastNE "Voter Salience in Last National Election"

generate VoterSalience_VI_NE = (MIP_Envi_VI_NE + MIP_CC_VI_NE) / VI_NE_Total *100
label variable VoterSalience_VI_NE "Voter Salience in Vote Intention for National Election"

generate VoterSalience_LastEP = (MIP_Envi_LastEP + MIP_CC_LastEP) / Vote_LastEP_Total *100
label variable VoterSalience_LastEP "Voter Salience in Last European Election"

xtset emcs year, delta(5)
gen PartySupporter1_shift = VoterSalience_VI_NE-L.VoterSalience_VI_NE
label variable PartySupporter1_shift " Shift of Altered Party Supporter Variable"

xtset emcs year, delta(5)
gen PartySupporter_shift = VoterSalience_LastNE-L.VoterSalience_LastNE
label variable PartySupporter_shift " Shift of Party Supporter Salience"

*Mean Voter
generate MeanVoterSalience = MIP_Envi_CC / Mean_Voter_Total *100
label variable MeanVoterSalience "Mean Voter Salience"

xtset emcs year, delta(5)
gen MeanVoter_shift = MeanVoterSalience-L.MeanVoterSalience
label variable MeanVoter_shift "Shift of Mean Voter Salience"

*Potential Voter
generate PotentialVoterSalience = (MIP_Envi_PV + MIP_CC_PV) / PV_Total *100
label variable PotentialVoterSalience "Potential Voter Salience"

xtset emcs year, delta(5)
gen PotentialVoter_shift = PotentialVoterSalience-L.PotentialVoterSalience
label variable PotentialVoter_shift "Shift of Potential Voter Salience"

save "Euromanifesto_vorbereitet.dta", replace



*preparation of the control variables


*control variable: Government vs. Opposition
recode gov (-666=.)
label variable gov "Government Party"

*control variable: Niche Party vs. Mainstream Party
generate nicheness = 0
replace nicheness = 1 if pfamily==1 |pfamily==95 |pfamily==9 |pfamily==7
label variable nicheness "Niche Party"
tab nicheness

*control variable: Vote Change
xtset emcs year, delta(5)
generate vote_change = NATvote-L.NATvote
label variable vote_change "Vote Change"
generate dummy_vote_loss = 0
replace dummy_vote_loss = 1 if vote_change < 0 //in order to make the interaction terms interpretable, a dummy variable is constructed
label variable dummy_vote_loss "Vote loss"


*control variable: Ideology
sum rile_mrg, detail
label variable rile_mrg "Left-Right Ideology"

*control variable: Green Party Family
generate green_party = 0
replace green_party = 1 if pfamily == 1
label variable green_party "Green Party Family"
tab green_party

*Creating interaction terms
generate int1 = PartySupporter_shift*nicheness
label variable int1 "Party Supporter × Nicheness"
generate int2 = PartySupporter_shift*dummy_vote_loss
label variable int2 "Party Supporter × Vote Loss"
generate int3 = MeanVoter_shift*gov
label variable int3 "Mean Voter × Government"

save "Euromanifesto_vorbereitet.dta", replace





***Descriptive Analysis ***
***Figure 7 (Thesis, p. 21)
by year, sort: egen MeanPartySalience = mean(envi_salience)
label variable MeanPartySalience "Mean of Parties' Issue Salience"
by year, sort: egen MeanIssueSalience = mean(MeanVoterSalience)
label variable MeanIssueSalience "Mean of Voters' Issue Salience"

graph twoway line MeanPartySalience MeanIssueSalience year, lp (solid dash) ///
ytitle("Salience in Percent", size(4)) xtitle("Election Year", size(4)) ///
xsca(titlegap(2)) ysca(titlegap(2)) ///
legend(col(1) order(1 2) size(4) label(1 "Mean of Parties' Issue Salience") ///
label(2 "Mean of Voters' Issue Salience")) ///
graphregion(fcolor(white)) ///
ylabel(,labsize(4)) xlabel(,labsize(4)) xlabel(1989(5)2014)	
graph set window fontface "Arial"
graph export "Mean_Voters_Parties.png", replace width(4000)

***Figure 3 (Appendix 2, p. 44)
graph bar MeanVoterSalience, over(country, sort(1) descending label(angle(45))) ///
ytitle("Mean Voter Salience in Percent", size(4)) ///
graphregion(fcolor(white)) ///
ylabel(,labsize(4)) ///
sort(country) 
graph set window fontface "Arial"
graph export "MeanVoter_Countries.png", replace width(4000)


***Figure 6 (Thesis, p. 20)
graph box PotentialVoterSalience VoterSalience_LastNE, over(pfamily) horizontal ///
graphregion(fcolor(white)) ///
legend(col(1) order(1 2) size(3) label(1 "Potential Voter Salience") ///
label(2 "Party Supporter Salience")) ///
graphregion(fcolor(white)) ///
ylabel(,labsize(3))
graph set window fontface "Arial"
graph export "Potential_Supporter_by_PartyFamilies.png", replace width(4000)


***Figure 5 (Thesis, p. 17)
generate position_reverse = -envi_position 
by year, sort: egen MeanPos = mean(position_reverse)
label variable MeanPos "Mean of Parties' Issue Position"

by year, sort: egen MeanSal = mean(envi_salience)
label variable MeanSal "Mean of Parties' Issue Salience"
generate MeanSal10 = MeanSal/10

twoway line MeanPos MeanSal10 year, sort clpattern(1 shortdash) ///
clcolor(black black) ///
legend(row(2) col(1) pos(11) order(1 "Mean Position" 2 "Mean Salience") ///
ring(0) size(medsmall) region(lc(white)) ) graphregion(color(white)) ///
yaxis(1 2) ytitle("Mean Position over Time") ///
ylabel(0(0.1)1.2 ,angle(horizontal)) xscale(titlegap(3)) ///
xtitle("Election Year") ylabel(, axis(2) angle(horizontal)) ///
xlabel(1989(5)2014) ///
ylabel(0(0.1)1.2 ,axis(2)) ///
ytitle("Mean Salience over Time", axis(2)) ///
scale(axis(2)) ///
yscale(titlegap(3) axis(2)) yscale(titlegap(3) axis(1))
graph set window fontface "Arial"
graph export "PosSal_Supply_Side.png", replace width(4000)


***Figure 2 (Appendix 2, p. 43)
graph box position_reverse, over(pfamily) horizontal graphregion(fcolor(white)) ///
ylabel(-3.5(1)5) ytitle("Position on the Environmental Issue", size(3.5))
graph set window fontface "Arial"
graph export "PosBox_Supply_Side.png", replace width(4000)


***Figure 1 (Appendix 2, p. 43)
twoway (line envi_salience year if emcs==51110, lp(solid)) ///
(line envi_salience year if emcs==51620, lp(longdash)) ///
(line envi_salience year if emcs==51320, lp(shortdash_dot)), ///
legend(col(2) symxsize(8) keygap(1) textwidth(23) order(1 3 2) size(3) label(1 "Green Party") ///
label(2 "Conservative Party") label(3 "Labour Party")) ///
graphregion(fcolor(white)) ///
xlabel(1989(5)2014, labsize(3)) ///
ylabel(,labsize(3)) ysca(titlegap(2)) ///
ytitle("Issue Salience", size(3)) ///
xtitle("Election Year", size(3)) ///
title("United Kingdom", size(3)) name(UK,replace)

twoway (line envi_salience year if emcs==41113, lp(solid)) ///
(line envi_salience year if emcs==41320, lp(longdash)) ///
(line envi_salience year if emcs==41521, lp(shortdash_dot)), ///
legend(col(2) symxsize(8) keygap(1) textwidth(23) order(1 3 2) size(3) label(1 "Alliance90/Greens") ///
label(2 "CDU") label(3 "SPD")) ///
graphregion(fcolor(white)) ///
xlabel(1989(5)2014, labsize(3)) ///
ylabel(,labsize(3)) ysca(titlegap(2)) ///
ytitle("Issue Salience", size(3)) ///
xtitle("Election Year", size(3)) ///
title("Germany", size(3)) name(Germany, replace)

twoway (line envi_salience year if emcs==11110, lp(solid)) ///
(line envi_salience year if emcs==11520, lp(longdash)) ///
(line envi_salience year if emcs==11320, lp(shortdash_dot)), ///
legend(col(2) symxsize(8) keygap(1) textwidth(23) order(1 3 2) size(3) label(1 "Greens Sweden") ///
label(2 "Christian Democrats") label(3 "Social Democrats")) ///
graphregion(fcolor(white)) ///
xlabel(1989(5)2014, labsize(3)) ///
ylabel(,labsize(3)) ysca(titlegap(2)) ///
ytitle("Issue Salience", size(3)) ///
xtitle("Election Year", size(3)) ///
title("Sweden", size(3)) name(Sweden, replace)

twoway (line envi_salience year if emcs==22110, lp(solid)) ///
(line envi_salience year if emcs==22521, lp(longdash)) ///
(line envi_salience year if emcs==22320, lp(shortdash_dot)), ///
legend(col(2) symxsize(8) keygap(1) textwidth(23) order(1 3 2) size(3) label(1 "Green Left") ///
label(2 "Christian Democratic Appeal") label(3 "Labour Party NL")) ///
graphregion(fcolor(white)) ///
xlabel(1989(5)2014, labsize(3)) ///
ylabel(,labsize(3)) ysca(titlegap(3)) ///
ytitle("Issue Salience", size(3)) ///
xtitle("Election Year", size(3)) ///
title("Netherlands", size(3)) name(Netherlands, replace)

graph combine UK Germany Sweden Netherlands, graphregion(fcolor(white)) name(PartySalience, replace)
graph set window fontface "Arial"
graph export "PartySalience.png", replace width(4000)



*The intial formula has negative values as indicator for pro-environmental positions.
*In order to have a more straightforward interpretation, the values are reversed
*Hence, the direction of the effect is the same as for the salience values
*(Positive values imply a higher issue-emphasis/more pro-environmentl position)
generate position_shift_rev = -position_shift 
label variable position_shift_rev "Shift of Parties' Position"

***Table for Descriptives
tabstat salience_shift position_shift_rev MeanVoter_shift PotentialVoter_shift ///
PartySupporter_shift nicheness gov vote_change green_party ///
rile_mrg, statistics(n mean sd min max) columns(statistics) format(%9.3f)

***Bivariate Correlations
corr position_shift_rev salience_shift MeanVoter_shift PotentialVoter_shift ///
PartySupporter_shift

***Checking Ezrow et al. 2010 Additional Analyses 
corr MeanVoter_shift PartySupporter_shift if nicheness==0
corr MeanVoter_shift PartySupporter_shift if nicheness==1

*Checking for normal distribution of DVs and IVs
hist salience_shift, normal name(SalienceHistogramm, replace) graphregion(fcolor(white))
hist position_shift_rev, normal name(PositionHistogramm, replace) graphregion(fcolor(white))
hist MeanVoter_shift, normal name(MeanVoterHistogramm, replace) graphregion(fcolor(white))
hist PotentialVoter_shift, normal name(PotentialVoterHistogramm, replace) graphregion(fcolor(white))
hist PartySupporter_shift, normal name(PartySupporterHistogramm, replace) graphregion(fcolor(white))
graph combine SalienceHistogramm PositionHistogramm MeanVoterHistogramm ///
PotentialVoterHistogramm PartySupporterHistogramm, graphregion(fcolor(white)) holes(3)
graph set window fontface "Arial"
graph export "DistributionHistogramms.png", replace width(4000)


save "Euromanifesto_vorbereitet.dta", replace




***Regression Analyses
* Installing the packages xtserial actest to check for autocorrelation
net from http://www.stata-journal.com/software/sj3-2/
net install st0039
ssc install actest
ssc install xtavplot
ssc instal xttest3


*Models with normal standard errors
*Model 1a
xtset country //setting the panel structure for the FE regression
xtreg salience_shift MeanVoter_shift i.year, fe cformat(%9.3f)
estimates store M1a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift MeanVoter_shift // test of autocorrelation

*Model 1b
xtset country //setting the panel structure for the FE regression
xtreg salience_shift PotentialVoter_shift i.year, fe cformat(%9.3f)
estimates store M1b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift PotentialVoter_shift // test of autocorrelation

*Model 1c
xtset country //setting the panel structure for the FE regression
xtreg salience_shift PartySupporter_shift i.year, fe cformat(%9.3f)
estimates store M1c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift PartySupporter_shift // test of autocorrelation

*Model 1d (+ Figure 5 (Appendix 3))
xtset country //setting the panel structure for the FE regression
xtreg salience_shift MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe cformat(%9.3f)
estimates store M1d
predict residuals_M1d, residuals
predict fitted_values_M1d, xb
scatter residuals_M1d fitted_values_M1d, graphregion(fcolor(white)) ///
xlabel(,labsize(3)) xsca(titlegap(2)) ylabel(,labsize(3)) ysca(titlegap(2))
graph set window fontface "Arial"
graph export "M1d_residual_plot.png", replace width(4000)
xttest3
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift MeanVoter_shift PotentialVoter_shift PartySupporter_shift // test of autocorrelation

estimates table M1a M1b M1c M1d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx begin
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 1 - DV: Salience Shift; normal SEs"),  font("Arial", 16) bold
putdocx table Model_1 = etable


*Model 2a
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev MeanVoter_shift i.year, fe cformat(%9.3f)
estimates store M2a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev MeanVoter_shift // test of autocorrelation

*Model 2b
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev PotentialVoter_shift i.year, fe cformat(%9.3f)
estimates store M2b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev PotentialVoter_shift // test of autocorrelation

*Model 2c
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev PartySupporter_shift i.year, fe cformat(%9.3f)
estimates store M2c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev PartySupporter_shift // test of autocorrelation

*Model 2d (+ Figure 6 (Appendix 3))
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe cformat(%9.3f)
estimates store M2d
predict residuals_M2d, residuals
predict fitted_values_M2d, xb
scatter residuals_M2d fitted_values_M2d, graphregion(fcolor(white)) ///
xlabel(, labsize(3)) xsca(titlegap(2)) ylabel(,labsize(3)) ysca(titlegap(2))
graph set window fontface "Arial"
graph export "M2d_residual_plot.png", replace width(4000)
xttest3
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev MeanVoter_shift PotentialVoter_shift PartySupporter_shift // test of autocorrelation

estimates table M2a M2b M2c M2d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 2 - DV: Position Shift; normal SEs"),  font("Arial", 16) bold
putdocx table Model_2 = etable



*Models with robust standard errors
*Model 3a
xtset country //setting the panel structure for the FE regression
xtreg salience_shift MeanVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M3a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift MeanVoter_shift // test of autocorrelation

*Model 3b
xtset country //setting the panel structure for the FE regression
xtreg salience_shift PotentialVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M3b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift PotentialVoter_shift // test of autocorrelation

*Model 3c
xtset country //setting the panel structure for the FE regression
xtreg salience_shift PartySupporter_shift i.year, fe robust cformat(%9.3f)
estimates store M3c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift PartySupporter_shift // test of autocorrelation

*Model 3d
xtset country //setting the panel structure for the FE regression
xtreg salience_shift MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M3d
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift MeanVoter_shift PotentialVoter_shift PartySupporter_shift // test of autocorrelation

estimates table M3a M3b M3c M3d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 3 - DV: Salience Shift; robust SEs"),  font("Arial", 16) bold
putdocx table Model_3 = etable


*Model 4a
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev MeanVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M4a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev MeanVoter_shift // test of autocorrelation

*Model 4b
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev PotentialVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M4b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev PotentialVoter_shift // test of autocorrelation

*Model 4c
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev PartySupporter_shift i.year, fe robust cformat(%9.3f)
estimates store M4c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev PartySupporter_shift // test of autocorrelation

*Model 4d
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M4d
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev MeanVoter_shift PotentialVoter_shift PartySupporter_shift // test of autocorrelation

estimates table M4a M4b M4c M4d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 4 - DV: Position Shift; robust SEs"),  font("Arial", 16) bold
putdocx table Model_4 = etable


*Models excluding parties with only marginal shifts in DVs and IVS 
*(thr= threshold)
generate salience_shift_thr = salience_shift 
replace salience_shift_thr = . if salience_shift_thr > -0.01 & salience_shift_thr < 0.01
generate position_shift_thr = position_shift_rev
replace position_shift_thr = . if position_shift_thr > -0.1 & position_shift_thr < 0.1
generate MeanVoter_shift_thr = MeanVoter_shift
replace MeanVoter_shift_thr = . if MeanVoter_shift_thr > -0.1 & MeanVoter_shift_thr < 0.1
generate PotentialVoter_shift_thr = PotentialVoter_shift
replace PotentialVoter_shift_thr = . if PotentialVoter_shift_thr == 0
generate PartySupporter_shift_thr = PartySupporter_shift
replace PartySupporter_shift_thr = . if PartySupporter_shift_thr == 0

*Model 5a
xtset country //setting the panel structure for the FE regression
xtreg salience_shift_thr MeanVoter_shift_thr i.year, fe robust cformat(%9.3f)
estimates store M5a
estimates table M5a, star stats(N r2 r2_a) b(%9.3f)
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift_thr MeanVoter_shift_thr // test of autocorrelation

*Model 5b
xtset country //setting the panel structure for the FE regression
xtreg salience_shift_thr PotentialVoter_shift_thr i.year, fe robust cformat(%9.3f)
estimates store M5b
estimates table M5b, star stats(N r2 r2_a) b(%9.3f)
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift_thr PotentialVoter_shift_thr // test of autocorrelation

*Model 5c
xtset country //setting the panel structure for the FE regression
xtreg salience_shift_thr PartySupporter_shift_thr i.year, fe robust cformat(%9.3f)
estimates store M5c
estimates table M5c, star stats(N r2 r2_a) b(%9.3f)
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift_thr PartySupporter_shift_thr // test of autocorrelation

*Model 5d
xtset country //setting the panel structure for the FE regression
xtreg salience_shift_thr MeanVoter_shift_thr PotentialVoter_shift_thr ///
PartySupporter_shift_thr i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M5d
estimates table M5d, star stats(N r2 r2_a) b(%9.3f)
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift_thr MeanVoter_shift_thr PotentialVoter_shift_thr ///
PartySupporter_shift_thr // test of autocorrelation

estimates table M5a M5b M5c M5d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift_thr PotentialVoter_shift_thr PartySupporter_shift_thr i.year ///
nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 5 - DV: Salience Shift; robust SEs; Threshold for small values"), font("Arial", 16) bold
putdocx table Model_5 = etable


*Model 6a
xtset country //setting the panel structure for the FE regression
xtreg position_shift_thr MeanVoter_shift_thr i.year, fe robust cformat(%9.3f)
estimates store M6a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_thr MeanVoter_shift_thr // test of autocorrelation

*Model 6b
xtset country //setting the panel structure for the FE regression
xtreg position_shift_thr PotentialVoter_shift_thr i.year, fe robust cformat(%9.3f)
estimates store M6b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_thr PotentialVoter_shift_thr // test of autocorrelation

*Model 6c
xtset country //setting the panel structure for the FE regression
xtreg position_shift_thr PartySupporter_shift_thr i.year, fe robust cformat(%9.3f)
estimates store M6c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_thr PartySupporter_shift_thr // test of autocorrelation

*Model 6d
xtset country //setting the panel structure for the FE regression
xtreg position_shift_thr MeanVoter_shift_thr PotentialVoter_shift_thr ///
PartySupporter_shift_thr i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M6d
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_thr MeanVoter_shift_thr PotentialVoter_shift_thr ///
PartySupporter_shift_thr // test of autocorrelation

estimates table M6a M6b M6c M6d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift_thr PotentialVoter_shift_thr PartySupporter_shift_thr i.year ///
nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 6 - DV: Position Shift; robust SEs; Threshold for small values"), font("Arial", 16) bold
putdocx table Model_6 = etable


*Models with log-transformation of IVs
generate LogMeanVoter_shift =  ln(MeanVoter_shift + sqrt(MeanVoter_shift^2 + 1))
label variable LogMeanVoter_shif "Log of Mean Voter Shift"
generate LogPotentialVoter_shift =  ln(PotentialVoter_shift + sqrt(PotentialVoter_shift^2 + 1))
label variable LogPotentialVoter_shift "Log of Potential Voter Shift"
generate LogPartySupporter_shift = ln(PartySupporter_shift + sqrt(PartySupporter_shift^2 + 1))
label variable LogPartySupporter_shift "Log of Party Supporter Shift"

*Model 7a
xtset country //setting the panel structure for the FE regression
xtreg salience_shift LogMeanVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M7a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift LogMeanVoter_shift // test of autocorrelation

*Model 7b
xtset country //setting the panel structure for the FE regression
xtreg salience_shift LogPotentialVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M7b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift LogPotentialVoter_shift // test of autocorrelation

*Model 7c
xtset country //setting the panel structure for the FE regression
xtreg salience_shift LogPartySupporter_shift i.year, fe robust cformat(%9.3f)
estimates store M7c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift LogPartySupporter_shift // test of autocorrelation

*Model 7d
xtset country //setting the panel structure for the FE regression
xtreg salience_shift LogMeanVoter_shift LogPotentialVoter_shift ///
LogPartySupporter_shift i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M7d
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift LogMeanVoter_shift LogPotentialVoter_shift  ///
LogPartySupporter_shift // test of autocorrelation

estimates table M7a M7b M7c M7d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(LogMeanVoter_shift LogPotentialVoter_shift LogPartySupporter_shift i.year ///
nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 7 - DV: Salience Shift; robust SEs; Log-transformation of DVs"), font("Arial", 16) bold
putdocx table Model_7 = etable


*Model 8a
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev LogMeanVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M8a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev LogMeanVoter_shift // test of autocorrelation

*Model 8b
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev LogPotentialVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M8b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev LogPotentialVoter_shift // test of autocorrelation

*Model 8c
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev LogPartySupporter_shift i.year, fe robust cformat(%9.3f)
estimates store M8c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev LogPartySupporter_shift // test of autocorrelation

*Model 8d
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev LogMeanVoter_shift LogPotentialVoter_shift ///
LogPartySupporter_shift i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M8d
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev LogMeanVoter_shift LogPotentialVoter_shift ///
LogPartySupporter_shift // test of autocorrelation

estimates table M8a M8b M8c M8d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(LogMeanVoter_shift LogPotentialVoter_shift LogPartySupporter_shift i.year ///
nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 8 - DV: Position Shift; robust SEs; Log-transformation of DVs"), font("Arial", 16) bold
putdocx table Model_8 = etable




*Models without shift variables (lagged dependent variable (ldv) instead)
xtset emcs year, delta(5)
generate ldv_position = L.envi_position
generate ldv_salience = L.envi_salience

*Model 9a
xtset country //setting the panel structure for the FE regression
xtreg envi_salience ldv_salience MeanVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M9a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial envi_salience MeanVoter_shift // test of autocorrelation

*Model 9b
xtset country //setting the panel structure for the FE regression
xtreg envi_salience ldv_salience PotentialVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M9b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial envi_salience PotentialVoter_shift // test of autocorrelation

*Model 9c
xtset country //setting the panel structure for the FE regression
xtreg envi_salience ldv_salience PartySupporter_shift i.year, fe robust cformat(%9.3f)
estimates store M9c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial envi_salience PartySupporter_shift // test of autocorrelation

*Model 9d
xtset country //setting the panel structure for the FE regression
xtreg envi_salience  ldv_salience MeanVoter_shift PotentialVoter_shift ///
PartySupporter_shift i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M9d
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial envi_salience MeanVoter_shift PotentialVoter_shift PartySupporter_shift // test of autocorrelation

estimates table M9a M9b M9c M9d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(ldv_salience MeanVoter_shift PotentialVoter_shift PartySupporter_shift i.year ///
nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 9 - DV: Salience Shift; robust SEs; LDV instead of shift variable"), font("Arial", 16) bold
putdocx table Model_9 = etable


*Model 10a
xtset country //setting the panel structure for the FE regression
xtreg position_reverse ldv_position MeanVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M10a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_reverse MeanVoter_shift // test of autocorrelation

*Model 10b
xtset country //setting the panel structure for the FE regression
xtreg position_reverse ldv_position PotentialVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M10b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_reverse PotentialVoter_shift // test of autocorrelation

*Model 10c
xtset country //setting the panel structure for the FE regression
xtreg position_reverse ldv_position PartySupporter_shift i.year, fe robust cformat(%9.3f)
estimates store M10c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_reverse PartySupporter_shift // test of autocorrelation

*Model 10d
xtset country //setting the panel structure for the FE regression
xtreg position_reverse ldv_position MeanVoter_shift PotentialVoter_shift  ///
PartySupporter_shift i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M10d
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_reverse MeanVoter_shift PotentialVoter_shift PartySupporter_shift // test of autocorrelation

estimates table M10a M10b M10c M10d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(ldv_position MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 10 - DV: Position Shift; robust SEs; LDV instead of shift variable"), font("Arial", 16) bold
putdocx table Model_10 = etable




*Models with different party supporter operationalization
* Vote intention instead of vote in last national election

*Model 11a
xtset country //setting the panel structure for the FE regression
xtreg salience_shift MeanVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M11a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift MeanVoter_shift // test of autocorrelation

*Model 11b
xtset country //setting the panel structure for the FE regression
xtreg salience_shift PotentialVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M11b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift PotentialVoter_shift // test of autocorrelation

*Model 11c
xtset country //setting the panel structure for the FE regression
xtreg salience_shift PartySupporter1_shift i.year, fe robust cformat(%9.3f)
estimates store M11c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift PartySupporter_shift // test of autocorrelation

*Model 11d
xtset country //setting the panel structure for the FE regression
xtreg salience_shift MeanVoter_shift PotentialVoter_shift ///
PartySupporter1_shift i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M11d
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift MeanVoter_shift LogPotentialVoter_shift  ///
PartySupporter1_shift // test of autocorrelation

estimates table M11a M11b M11c M11d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter1_shift i.year ///
nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 11 - DV: Salience Shift; robust SEs; different party supporter operationalisation"), font("Arial", 16) bold
putdocx table Model_11 = etable


*Model 12a
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev MeanVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M12a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev MeanVoter_shift // test of autocorrelation

*Model 12b
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev PotentialVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M12b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev LogPotentialVoter_shift // test of autocorrelation

*Model 12c
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev PartySupporter1_shift i.year, fe robust cformat(%9.3f)
estimates store M12c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev PartySupporter1_shift // test of autocorrelation

*Model 12d
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev MeanVoter_shift PotentialVoter_shift ///
PartySupporter1_shift i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M12d
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev MeanVoter_shift PotentialVoter_shift ///
PartySupporter1_shift // test of autocorrelation

estimates table M12a M12b M12c M12d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter1_shift i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 12 - DV: Position Shift; robust SEs; different party supporter operationalisation"), font("Arial", 16) bold
putdocx table Model_12 = etable



*Models with different position operationalisation
generate envi_position1 = log(abs401a_all + abs410a_all + 0.5) - log(abs501a_all + abs416a_all + 0.5)
label variable envi_position1 "Position1 on Environmental Issue"
tab envi_position1
sum envi_position1
xtset emcs year, delta(5)
gen position_shift1 = envi_position1-L.envi_position1
replace position_shift1 = -position_shift1

*Model 13a
xtset country //setting the panel structure for the FE regression
xtreg position_shift1 MeanVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M13a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift1 MeanVoter_shift // test of autocorrelation

*Model 13b
xtset country //setting the panel structure for the FE regression
xtreg position_shift1 PotentialVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M13b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift1 PotentialVoter_shift // test of autocorrelation

*Model 13c
xtset country //setting the panel structure for the FE regression
xtreg position_shift1 PartySupporter_shift i.year, fe robust cformat(%9.3f)
estimates store M13c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift1 PartySupporter_shift // test of autocorrelation

*Model 13d
xtset country //setting the panel structure for the FE regression
xtreg position_shift1 MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M13d
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift1 MeanVoter_shift LogPotentialVoter_shift ///
LogPartySupporter_shift // test of autocorrelation

estimates table M13a M13b M13c M13d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 13 - DV: Position Shift; robust SEs; different position operationalisation"), font("Arial", 16) bold
putdocx table Model_13 = etable


*Absolute position shift values
generate position_shift2 = abs(position_shift_rev)

*Model 14a
xtset country //setting the panel structure for the FE regression
xtreg position_shift2 MeanVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M14a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift2 MeanVoter_shift // test of autocorrelation

*Model 14b
xtset country //setting the panel structure for the FE regression
xtreg position_shift2 PotentialVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M14b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift2 PotentialVoter_shift // test of autocorrelation

*Model 14c
xtset country //setting the panel structure for the FE regression
xtreg position_shift2 PartySupporter_shift i.year, fe robust cformat(%9.3f)
estimates store M14c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift2 PartySupporter_shift // test of autocorrelation

*Model 14d
xtset country //setting the panel structure for the FE regression
xtreg position_shift2 MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M14d
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift2 MeanVoter_shift PotentialVoter_shift PartySupporter_shift // test of autocorrelation

estimates table M14a M14b M14c M14d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 14 - DV: Position Shift; robust SEs; only absolute position values"), font("Arial", 16) bold
putdocx table Model_14 = etable




*Including only countries with data for all elections (allE= all Elections)
generate salience_shift_allE = salience_shift if country==13 |country==21 ///
|country==22 |country==23 |country==31 |country==33 |country==35 |country==34 ///
|country==51 |country==53
generate position_shift_allE = position_shift_rev if country==13 |country==21 ///
|country==22 |country==23 |country==31 |country==33 |country==35 |country==34 ///
|country==51 |country==53

*Model 15a
xtset country //setting the panel structure for the FE regression
xtreg salience_shift_allE MeanVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M15a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift MeanVoter_shift // test of autocorrelation

*Model 15b
xtset country //setting the panel structure for the FE regression
xtreg salience_shift_allE PotentialVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M15b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift PotentialVoter_shift // test of autocorrelation

*Model 15c
xtset country //setting the panel structure for the FE regression
xtreg salience_shift_allE PartySupporter_shift i.year, fe robust cformat(%9.3f)
estimates store M15c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift PartySupporter_shift // test of autocorrelation

*Model 15d
xtset country //setting the panel structure for the FE regression
xtreg salience_shift_allE MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M15d
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift MeanVoter_shift PotentialVoter_shift PartySupporter_shift // test of autocorrelation

estimates table M15a M15b M15c M15d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift i.year ///
nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 15 - DV: Salience Shift; robust SEs; all Elections"), ///
font("Arial", 16) bold
putdocx table Model_15 = etable


*Model 16a
xtset country //setting the panel structure for the FE regression
xtreg position_shift_allE MeanVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M16a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev MeanVoter_shift // test of autocorrelation

*Model 16b
xtset country //setting the panel structure for the FE regression
xtreg position_shift_allE PotentialVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M16b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev PotentialVoter_shift // test of autocorrelation

*Model 16c
xtset country //setting the panel structure for the FE regression
xtreg position_shift_allE PartySupporter_shift i.year, fe robust cformat(%9.3f)
estimates store M16c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev PartySupporter_shift // test of autocorrelation

*Model 16d
xtset country //setting the panel structure for the FE regression
xtreg position_shift_allE MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M16d
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev MeanVoter_shift PotentialVoter_shift PartySupporter_shift // test of autocorrelation

estimates table M16a M16b M16c M16d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift i.year ///
nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 16 - DV: Position Shift; robust SEs; all Elections"),  font("Arial", 16) bold
putdocx table Model_16 = etable





*Excluding the Eastern European countries (woEE= without Eastern Europe)
generate salience_shift_woEE = salience_shift 
replace salience_shift_woEE = . if country==82 |country==83 |country==86 ///
|country==92 |country==96 |country==97
generate position_shift_woEE = position_shift_rev
replace position_shift_woEE = . if country==82 |country==83 |country==86 ///
|country==92 |country==96 |country==97

*Model 17a
xtset country //setting the panel structure for the FE regression
xtreg salience_shift_woEE MeanVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M17a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift MeanVoter_shift // test of autocorrelation

*Model 17b
xtset country //setting the panel structure for the FE regression
xtreg salience_shift_woEE PotentialVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M17b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift PotentialVoter_shift // test of autocorrelation

*Model 17c
xtset country //setting the panel structure for the FE regression
xtreg salience_shift_woEE PartySupporter_shift i.year, fe robust cformat(%9.3f)
estimates store M17c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift PartySupporter_shift // test of autocorrelation

*Model 17d
xtset country //setting the panel structure for the FE regression
xtreg salience_shift_woEE MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M17d
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift MeanVoter_shift PotentialVoter_shift PartySupporter_shift // test of autocorrelation

estimates table M17a M17b M17c M17d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift i.year ///
nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 17 - DV: Salience Shift; robust SEs; without Eastern Europe"), ///
font("Arial", 16) bold
putdocx table Model_17 = etable


*Model 18a
xtset country //setting the panel structure for the FE regression
xtreg position_shift_woEE MeanVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M18a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev MeanVoter_shift // test of autocorrelation

*Model 18b
xtset country //setting the panel structure for the FE regression
xtreg position_shift_woEE PotentialVoter_shift i.year, fe robust cformat(%9.3f)
estimates store M18b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev PotentialVoter_shift // test of autocorrelation

*Model 18c
xtset country //setting the panel structure for the FE regression
xtreg position_shift_woEE PartySupporter_shift i.year, fe robust cformat(%9.3f)
estimates store M18c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev PartySupporter_shift // test of autocorrelation

*Model 18d
xtset country //setting the panel structure for the FE regression
xtreg position_shift_woEE MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M18d
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev MeanVoter_shift PotentialVoter_shift PartySupporter_shift // test of autocorrelation

estimates table M18a M18b M18c M18d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift i.year ///
nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 18 - DV: Position Shift; robust SEs; without Eastern Europe"),  font("Arial", 16) bold
putdocx table Model_18 = etable




*OLS regression without fixed effects and with normal standard errors
*Model 19a
reg salience_shift MeanVoter_shift i.year, cformat(%9.3f)
estimates store M19a
vif // test of multicollinearity
actest // test of autocorrelation
hettest // test of homoskedasticity

*Model 19b
reg salience_shift PotentialVoter_shift i.year, cformat(%9.3f)
estimates store M19b
vif // test of multicollinearity
actest // test of autocorrelation
hettest // test of homoskedasticity

*Model 19c
reg salience_shift PartySupporter_shift i.year, cformat(%9.3f)
estimates store M19c
vif // test of multicollinearity
actest // test of autocorrelation
hettest // test of homoskedasticity

*Model 19d
reg salience_shift MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, cformat(%9.3f)
estimates store M19d
vif // test of multicollinearity
actest // test of autocorrelation
hettest // test of homoskedasticity

estimates table M19a M19b M19c M19d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift i.year ///
nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 19 - no FE; DV: Salience Shift; normal SEs"),  font("Arial", 16) bold
putdocx table Model_19 = etable


*Model 20a
reg position_shift_rev MeanVoter_shift i.year, cformat(%9.3f)
estimates store M20a
vif // test of multicollinearity
actest // test of autocorrelation
hettest // test of homoskedasticity

*Model 20b
reg position_shift_rev PotentialVoter_shift i.year, cformat(%9.3f)
estimates store M20b
vif // test of multicollinearity
actest // test of autocorrelation
hettest // test of homoskedasticity

*Model 20c
reg position_shift_rev PartySupporter_shift i.year, cformat(%9.3f)
estimates store M20c
vif // test of multicollinearity
actest // test of autocorrelation
hettest // test of homoskedasticity

*Model 20d
reg position_shift_rev MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, cformat(%9.3f)
estimates store M20d
vif // test of multicollinearity
actest // test of autocorrelation
hettest // test of homoskedasticity

estimates table M20a M20b M20c M20d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift i.year ///
nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 20 - no FE; DV: Position Shift; normal SEs"),  font("Arial", 16) bold
putdocx table Model_20 = etable




*OLS regression without fixed effects and with robust standard errors
*Model 21a
reg salience_shift MeanVoter_shift i.year, robust cformat(%9.3f)
estimates store M21a
vif // test of multicollinearity
actest // test of autocorrelation

*Model 21b
reg salience_shift PotentialVoter_shift i.year, robust cformat(%9.3f)
estimates store M21b
vif // test of multicollinearity
actest // test of autocorrelation

*Model 21c
reg salience_shift PartySupporter_shift i.year, robust cformat(%9.3f)
estimates store M21c
vif // test of multicollinearity
actest // test of autocorrelation

*Model 21d
reg salience_shift MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, robust cformat(%9.3f)
estimates store M21d
vif // test of multicollinearity
actest // test of autocorrelation

estimates table M21a M21b M21c M21d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift i.year ///
nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 21 - no FE; DV: Salience Shift; robust SEs"),  font("Arial", 16) bold
putdocx table Model_21 = etable


*Model 22a
reg position_shift_rev MeanVoter_shift i.year, robust cformat(%9.3f)
estimates store M22a
vif // test of multicollinearity
actest // test of autocorrelation

*Model 22b
reg position_shift_rev PotentialVoter_shift i.year, robust cformat(%9.3f)
estimates store M22b
vif // test of multicollinearity
actest // test of autocorrelation

*Model 22c
reg position_shift_rev PartySupporter_shift i.year, robust cformat(%9.3f)
estimates store M22c
vif // test of multicollinearity
actest // test of autocorrelation

*Model 22d
reg position_shift_rev MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, robust cformat(%9.3f)
estimates store M22d
vif // test of multicollinearity
actest // test of autocorrelation

estimates table M22a M22b M22c M22d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift i.year ///
nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 22 - no FE; DV: Position Shift; robust SEs"), font("Arial", 16) bold
putdocx table Model_22 = etable




*OLS regression without fixed effects and with clustered standard errors
*Model 23a
reg salience_shift MeanVoter_shift i.year, cluster(country) cformat(%9.3f)
estimates store M23a
vif // test of multicollinearity
actest // test of autocorrelation

*Model 23b
reg salience_shift PotentialVoter_shift i.year, cluster(country) cformat(%9.3f)
estimates store M23b
vif // test of multicollinearity
actest // test of autocorrelation

*Model 23c
reg salience_shift PartySupporter_shift i.year, cluster(country) cformat(%9.3f)
estimates store M23c
vif // test of multicollinearity
actest // test of autocorrelation

*Model 23d
reg salience_shift MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, cluster(country) cformat(%9.3f)
estimates store M23d
vif // test of multicollinearity
actest // test of autocorrelation

estimates table M23a M23b M23c M23d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift i.year ///
nicheness gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 23 - no FE; DV: Salience Shift; clustered SEs"),  font("Arial", 16) bold
putdocx table Model_23 = etable


*Model 24a
reg position_shift_rev MeanVoter_shift i.year, cluster(country) cformat(%9.3f)
estimates store M24a
vif // test of multicollinearity
actest // test of autocorrelation

*Model 24b
reg position_shift_rev PotentialVoter_shift i.year, cluster(country) cformat(%9.3f)
estimates store M24b
vif // test of multicollinearity
actest // test of autocorrelation

*Model 24c
reg position_shift_rev PartySupporter_shift i.year, cluster(country) cformat(%9.3f)
estimates store M24c
vif // test of multicollinearity
actest // test of autocorrelation

*Model 24d
reg position_shift_rev MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, ///
cluster(country) cformat(%9.3f)
estimates store M24d
vif // test of multicollinearity
actest // test of autocorrelation

estimates table M24a M24b M24c M24d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift i.year nicheness ///
gov vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 24 - no FE; DV: Position Shift; clustered SEs"), font("Arial", 16) bold
putdocx table Model_24 = etable




*FE Models without years 
*Model 25a
xtset country //setting the panel structure for the FE regression
xtreg salience_shift MeanVoter_shift, fe robust cformat(%9.3f)
estimates store M25a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift MeanVoter_shift // test of autocorrelation

*Model 25b
xtset country //setting the panel structure for the FE regression
xtreg salience_shift PotentialVoter_shift, fe robust cformat(%9.3f)
estimates store M25b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift PotentialVoter_shift // test of autocorrelation

*Model 25c
xtset country //setting the panel structure for the FE regression
xtreg salience_shift PartySupporter_shift, fe robust cformat(%9.3f)
estimates store M25c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift PartySupporter_shift // test of autocorrelation

*Model 25d
xtset country //setting the panel structure for the FE regression
xtreg salience_shift MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M25d
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial salience_shift MeanVoter_shift PotentialVoter_shift PartySupporter_shift // test of autocorrelation

estimates table M25a M25b M25c M25d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift nicheness gov ///
 vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 25 - DV: Salience Shift; robust SEs; without years"),  ///
font("Arial", 16) bold
putdocx table Model_25 = etable


*Model 26a
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev MeanVoter_shift, fe robust cformat(%9.3f)
estimates store M26a
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev MeanVoter_shift // test of autocorrelation

*Model 26b
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev PotentialVoter_shift, fe robust cformat(%9.3f)
estimates store M26b
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev PotentialVoter_shift // test of autocorrelation

*Model 26c
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev PartySupporter_shift, fe robust cformat(%9.3f)
estimates store M26c
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev PartySupporter_shift // test of autocorrelation

*Model 26d
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
estimates store M26d
vif, uncentered // test of multicollinearity
xtset emcs year, delta(5) // setting panel structure for test of autocorrelation
xtserial position_shift_rev MeanVoter_shift PotentialVoter_shift PartySupporter_shift // test of autocorrelation

estimates table M26a M26b M26c M26d, star stats(N r2 r2_a) b(%9.3f) varlabel ///
keep(MeanVoter_shift PotentialVoter_shift PartySupporter_shift nicheness gov ///
vote_change green_party rile_mrg int1 int2 int3 _cons) 
putdocx paragraph, font("Arial", 16)
putdocx text ("Model 26 - DV: Position Shift; robust SEs; without Years"),  ///
font("Arial", 16) bold
putdocx table Model_26 = etable


putdocx save "regression_tables.docx", replace


*Margins Plot Model 3d (Figure 8, Thesis p. 23)
xtset country //setting the panel structure for the FE regression
xtreg salience_shift MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness i.gov vote_change green_party rile_mrg , fe robust cformat(%9.3f)
margins, at(PotentialVoter_shift= (-40 (10) 30)) vsquish
marginsplot,  level(95) plotopts(lcolor(black) clpattern(line) lwidth(medthin)) ///
recast(line) recastci(rarea) graphregion(fcolor(white)) ///
ciopts (lcolor(gs16) clpattern(line) lpattern(dash) color(gs12) lwidth(medthck)) ///
xtitle(, size(3)) xlabel(, labsize(3)) ylabel(, labsize(3))  ///
ytitle("Marginal Effect of Parties' Salience Shift", size(3)) ///
title("")
graph set window fontface "Arial"
graph export "M3d_marginsplots.png", replace width(4000)

*Margins Plot Model 4d (Figure 9, Thesis p. 27)
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness i.gov vote_change green_party rile_mrg, fe robust cformat(%9.3f)
margins, at(MeanVoter_shift= (-40 (10) 30)) vsquish
marginsplot,  level(95) plotopts(lcolor(black) clpattern(line) lwidth(medthin)) ///
recast(line) recastci(rarea) graphregion(fcolor(white)) ///
ciopts (lcolor(gs16) clpattern(line) lpattern(dash) color(gs12) lwidth(medthck)) ///
xtitle(, size(3)) xlabel(, labsize(3)) ylabel(, labsize(3))  ///
ytitle("Marginal Effect of Parties' Position Shift", size(3)) ///
title("")
graph set window fontface "Arial"
graph export "M4d_marginsplots.png", replace width(4000)

*Partial Regression Plot (Figure 9, Appendix 3)
xtset country //setting the panel structure for the FE regression
xtreg salience_shift MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness i.gov vote_change green_party rile_mrg , fe robust cformat(%9.3f)
xtavplot MeanVoter_shift, graphregion(fcolor(white)) ///
ytitle("Residuals of Mean Voter Shift", size(3)) ///
xtitle("Residuals of Salience Shift", size(3)) xlabel(, labsize(3)) ///
xsca(titlegap(2)) ylabel(,labsize(3)) ysca(titlegap(2)) ///
title("Mean Voter Shift", size(3)) name(MeanVoter, replace)
xtavplot PotentialVoter_shift, graphregion(fcolor(white)) ///
ytitle("Residuals of Potential Voter Shift", size(3)) ///
xtitle("Residuals of Salience Shift", size(3)) xlabel(, labsize(3)) ///
xsca(titlegap(2)) ylabel(,labsize(3)) ysca(titlegap(2)) ///
title("Potential Voter Shift", size(3)) name(PotentialVoter, replace)
xtavplot PartySupporter_shift, graphregion(fcolor(white)) ///
ytitle("Residuals of Party Supporter Shift", size(3)) ///
xtitle("Residuals of Salience Shift", size(3)) xlabel(, labsize(3)) ///
xsca(titlegap(2)) ylabel(,labsize(3)) ysca(titlegap(2)) ///
title("Party Supporter Shift", size(3)) name(PartySupporter, replace)
graph combine MeanVoter PotentialVoter PartySupporter, ///
graphregion(fcolor(white)) name(xtavplots, replace)
graph set window fontface "Arial"
graph export "M3d_xtavplots.png", replace width(4000)


*Partial Regression Plot (Figure 10, Appendix 3)
xtset country //setting the panel structure for the FE regression
xtreg position_shift MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
xtavplot MeanVoter_shift, graphregion(fcolor(white)) ///
ytitle("Residuals of Mean Voter Shift", size(3)) ///
xtitle("Residuals of Position Shift", size(3)) xlabel(, labsize(3)) ///
xsca(titlegap(2)) ylabel(,labsize(3)) ysca(titlegap(2)) ///
title("Mean Voter Shift", size(3)) name(MeanVoter, replace)
xtavplot PotentialVoter_shift, graphregion(fcolor(white)) ///
ytitle("Residuals of Potential Voter Shift", size(3)) ///
xtitle("Residuals of Position Shift", size(3)) xlabel(, labsize(3)) ///
xsca(titlegap(2)) ylabel(,labsize(3)) ysca(titlegap(2)) ///
title("Potential Voter Shift", size(3)) name(PotentialVoter, replace)
xtavplot PartySupporter_shift, graphregion(fcolor(white)) ///
ytitle("Residuals of Party Supporter Shift", size(3)) ///
xtitle("Residuals of Position Shift", size(3)) xlabel(, labsize(3)) ///
xsca(titlegap(2)) ylabel(,labsize(3)) ysca(titlegap(2)) ///
title("Party Supporter Shift", size(3)) name(PartySupporter, replace)
graph combine MeanVoter PotentialVoter PartySupporter, ///
graphregion(fcolor(white)) name(xtavplots, replace)
graph set window fontface "Arial"
graph export "M4d_xtavplots.png", replace width(4000)


*Distribution of Residuals for Emphasis-based Policy Change (Figure 7, Appendix 3)
xtset country //setting the panel structure for the FE regression
xtreg salience_shift MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
predict residuals_M3d, residuals
hist residuals_M3d, density normal graphregion(fcolor(white)) ytitle(, size(3)) ///
xtitle("Residuals of Salience Shift", size(3)) xlabel(, labsize(3)) ylabel(, labsize(3))
graph set window fontface "Arial"
graph export "M3d_residual_histogramm.png", replace width(4000)


*Distribution of Residuals for Opinion-based Policy Change (Figure 8, Appendix 3)
xtset country //setting the panel structure for the FE regression
xtreg position_shift_rev MeanVoter_shift PotentialVoter_shift PartySupporter_shift ///
i.year nicheness gov vote_change green_party rile_mrg int1 int2 int3, fe robust cformat(%9.3f)
predict residuals_M4d, residuals
hist residuals_M4d, density normal graphregion(fcolor(white)) ytitle(, size(3))  ///
xtitle("Residuals of Position Shift", size(3)) xlabel(, labsize(3)) ylabel(, labsize(3))
graph set window fontface "Arial"
graph export "M4d_residual_histogramm.png", replace width(4000)


save "Euromanifesto_vorbereitet.dta", replace
log close
translate Responsiveness_Paper_log.smcl Responsiveness_Paper_log.pdf
